==> efs-1.60.0-sources.jar: software/amazon/awscdk/services/efs/AccessPointOptions.java <==
package software.amazon.awscdk.services.efs;

/**
 * Options to create an AccessPoint.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.217Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.efs.$Module.class, fqn = "@aws-cdk/aws-efs.AccessPointOptions")
@software.amazon.jsii.Jsii.Proxy(AccessPointOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AccessPointOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Specifies the POSIX IDs and permissions to apply when creating the access point's root directory.
     * <p>
     * If the
     * root directory specified by <code>path</code> does not exist, EFS creates the root directory and applies the
     * permissions specified here. If the specified <code>path</code> does not exist, you must specify <code>createAcl</code>.
     * <p>
     * Default: - None. The directory specified by `path` must exist.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.efs.Acl getCreateAcl() {
        return null;
    }

    /**
     * Specifies the path on the EFS file system to expose as the root directory to NFS clients using the access point to access the EFS file system.
     * <p>
     * Default: '/'
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getPath() {
        return null;
    }

    /**
     * The full POSIX identity, including the user ID, group ID, and any secondary group IDs, on the access point that is used for all file system operations performed by NFS clients using the access point.
     * <p>
     * Specify this to enforce a user identity using an access point.
     * <p>
     * Default: - user identity not enforced
     * <p>
     * EXPERIMENTAL
     * <p>
     * @see - [Enforcing a User Identity Using an Access Point](https://docs.aws.amazon.com/efs/latest/ug/efs-access-points.html)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.efs.PosixUser getPosixUser() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AccessPointOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AccessPointOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<AccessPointOptions> {
        private software.amazon.awscdk.services.efs.Acl createAcl;
        private java.lang.String path;
        private software.amazon.awscdk.services.efs.PosixUser posixUser;

        /**
         * Sets the value of {@link AccessPointOptions#getCreateAcl}
         * @param createAcl Specifies the POSIX IDs and permissions to apply when creating the access point's root directory.
         *                  If the
         *                  root directory specified by <code>path</code> does not exist, EFS creates the root directory and applies the
         *                  permissions specified here. If the specified <code>path</code> does not exist, you must specify <code>createAcl</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder createAcl(software.amazon.awscdk.services.efs.Acl createAcl) {
            this.createAcl = createAcl;
            return this;
        }

        /**
         * Sets the value of {@link AccessPointOptions#getPath}
         * @param path Specifies the path on the EFS file system to expose as the root directory to NFS clients using the access point to access the EFS file system.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder path(java.lang.String path) {
            this.path = path;
            return this;
        }

        /**
         * Sets the value of {@link AccessPointOptions#getPosixUser}
         * @param posixUser The full POSIX identity, including the user ID, group ID, and any secondary group IDs, on the access point that is used for all file system operations performed by NFS clients using the access point.
         *                  Specify this to enforce a user identity using an access point.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder posixUser(software.amazon.awscdk.services.efs.PosixUser posixUser) {
            this.posixUser = posixUser;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AccessPointOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public AccessPointOptions build() {
            return new Jsii$Proxy(createAcl, path, posixUser);
        }
    }

    /**
     * An implementation for {@link AccessPointOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AccessPointOptions {
        private final software.amazon.awscdk.services.efs.Acl createAcl;
        private final java.lang.String path;
        private final software.amazon.awscdk.services.efs.PosixUser posixUser;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.createAcl = this.jsiiGet("createAcl", software.amazon.awscdk.services.efs.Acl.class);
            this.path = this.jsiiGet("path", java.lang.String.class);
            this.posixUser = this.jsiiGet("posixUser", software.amazon.awscdk.services.efs.PosixUser.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.efs.Acl createAcl, final java.lang.String path, final software.amazon.awscdk.services.efs.PosixUser posixUser) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.createAcl = createAcl;
            this.path = path;
            this.posixUser = posixUser;
        }

        @Override
        public software.amazon.awscdk.services.efs.Acl getCreateAcl() {
            return this.createAcl;
        }

        @Override
        public java.lang.String getPath() {
            return this.path;
        }

        @Override
        public software.amazon.awscdk.services.efs.PosixUser getPosixUser() {
            return this.posixUser;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCreateAcl() != null) {
                data.set("createAcl", om.valueToTree(this.getCreateAcl()));
            }
            if (this.getPath() != null) {
                data.set("path", om.valueToTree(this.getPath()));
            }
            if (this.getPosixUser() != null) {
                data.set("posixUser", om.valueToTree(this.getPosixUser()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-efs.AccessPointOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AccessPointOptions.Jsii$Proxy that = (AccessPointOptions.Jsii$Proxy) o;

            if (this.createAcl != null ? !this.createAcl.equals(that.createAcl) : that.createAcl != null) return false;
            if (this.path != null ? !this.path.equals(that.path) : that.path != null) return false;
            return this.posixUser != null ? this.posixUser.equals(that.posixUser) : that.posixUser == null;
        }

        @Override
        public int hashCode() {
            int result = this.createAcl != null ? this.createAcl.hashCode() : 0;
            result = 31 * result + (this.path != null ? this.path.hashCode() : 0);
            result = 31 * result + (this.posixUser != null ? this.posixUser.hashCode() : 0);
            return result;
        }
    }
}

==> efs-1.93.0-sources.jar: software/amazon/awscdk/services/efs/AccessPointOptions.java <==
package software.amazon.awscdk.services.efs;

/**
 * (experimental) Options to create an AccessPoint.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.402Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.efs.$Module.class, fqn = "@aws-cdk/aws-efs.AccessPointOptions")
@software.amazon.jsii.Jsii.Proxy(AccessPointOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AccessPointOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Specifies the POSIX IDs and permissions to apply when creating the access point's root directory.
     * <p>
     * If the
     * root directory specified by <code>path</code> does not exist, EFS creates the root directory and applies the
     * permissions specified here. If the specified <code>path</code> does not exist, you must specify <code>createAcl</code>.
     * <p>
     * Default: - None. The directory specified by `path` must exist.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.efs.Acl getCreateAcl() {
        return null;
    }

    /**
     * (experimental) Specifies the path on the EFS file system to expose as the root directory to NFS clients using the access point to access the EFS file system.
     * <p>
     * Default: '/'
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getPath() {
        return null;
    }

    /**
     * (experimental) The full POSIX identity, including the user ID, group ID, and any secondary group IDs, on the access point that is used for all file system operations performed by NFS clients using the access point.
     * <p>
     * Specify this to enforce a user identity using an access point.
     * <p>
     * Default: - user identity not enforced
     * <p>
     * @see - [Enforcing a User Identity Using an Access Point](https://docs.aws.amazon.com/efs/latest/ug/efs-access-points.html)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.efs.PosixUser getPosixUser() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AccessPointOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AccessPointOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<AccessPointOptions> {
        private software.amazon.awscdk.services.efs.Acl createAcl;
        private java.lang.String path;
        private software.amazon.awscdk.services.efs.PosixUser posixUser;

        /**
         * Sets the value of {@link AccessPointOptions#getCreateAcl}
         * @param createAcl Specifies the POSIX IDs and permissions to apply when creating the access point's root directory.
         *                  If the
         *                  root directory specified by <code>path</code> does not exist, EFS creates the root directory and applies the
         *                  permissions specified here. If the specified <code>path</code> does not exist, you must specify <code>createAcl</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder createAcl(software.amazon.awscdk.services.efs.Acl createAcl) {
            this.createAcl = createAcl;
            return this;
        }

        /**
         * Sets the value of {@link AccessPointOptions#getPath}
         * @param path Specifies the path on the EFS file system to expose as the root directory to NFS clients using the access point to access the EFS file system.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder path(java.lang.String path) {
            this.path = path;
            return this;
        }

        /**
         * Sets the value of {@link AccessPointOptions#getPosixUser}
         * @param posixUser The full POSIX identity, including the user ID, group ID, and any secondary group IDs, on the access point that is used for all file system operations performed by NFS clients using the access point.
         *                  Specify this to enforce a user identity using an access point.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder posixUser(software.amazon.awscdk.services.efs.PosixUser posixUser) {
            this.posixUser = posixUser;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AccessPointOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public AccessPointOptions build() {
            return new Jsii$Proxy(createAcl, path, posixUser);
        }
    }

    /**
     * An implementation for {@link AccessPointOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AccessPointOptions {
        private final software.amazon.awscdk.services.efs.Acl createAcl;
        private final java.lang.String path;
        private final software.amazon.awscdk.services.efs.PosixUser posixUser;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.createAcl = software.amazon.jsii.Kernel.get(this, "createAcl", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.efs.Acl.class));
            this.path = software.amazon.jsii.Kernel.get(this, "path", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.posixUser = software.amazon.jsii.Kernel.get(this, "posixUser", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.efs.PosixUser.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.efs.Acl createAcl, final java.lang.String path, final software.amazon.awscdk.services.efs.PosixUser posixUser) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.createAcl = createAcl;
            this.path = path;
            this.posixUser = posixUser;
        }

        @Override
        public final software.amazon.awscdk.services.efs.Acl getCreateAcl() {
            return this.createAcl;
        }

        @Override
        public final java.lang.String getPath() {
            return this.path;
        }

        @Override
        public final software.amazon.awscdk.services.efs.PosixUser getPosixUser() {
            return this.posixUser;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCreateAcl() != null) {
                data.set("createAcl", om.valueToTree(this.getCreateAcl()));
            }
            if (this.getPath() != null) {
                data.set("path", om.valueToTree(this.getPath()));
            }
            if (this.getPosixUser() != null) {
                data.set("posixUser", om.valueToTree(this.getPosixUser()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-efs.AccessPointOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AccessPointOptions.Jsii$Proxy that = (AccessPointOptions.Jsii$Proxy) o;

            if (this.createAcl != null ? !this.createAcl.equals(that.createAcl) : that.createAcl != null) return false;
            if (this.path != null ? !this.path.equals(that.path) : that.path != null) return false;
            return this.posixUser != null ? this.posixUser.equals(that.posixUser) : that.posixUser == null;
        }

        @Override
        public final int hashCode() {
            int result = this.createAcl != null ? this.createAcl.hashCode() : 0;
            result = 31 * result + (this.path != null ? this.path.hashCode() : 0);
            result = 31 * result + (this.posixUser != null ? this.posixUser.hashCode() : 0);
            return result;
        }
    }
}
